@@ -27,6 +27,7 @@ from .type_defs import (
     DescribeAppInstanceResponseTypeDef,
     DescribeAppInstanceUserEndpointResponseTypeDef,
     DescribeAppInstanceUserResponseTypeDef,
+    EmptyResponseMetadataTypeDef,
     EndpointAttributesTypeDef,
     GetAppInstanceRetentionSettingsResponseTypeDef,
     ListAppInstanceAdminsResponseTypeDef,
@@ -96,7 +97,7 @@ class ChimeSDKIdentityClient(BaseClient):
         Name: str,
         ClientRequestToken: str,
         Metadata: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CreateAppInstanceResponseTypeDef:
         """
         Creates an Amazon Chime SDK messaging `AppInstance` under an AWS account.
@@ -123,7 +124,7 @@ class ChimeSDKIdentityClient(BaseClient):
         Name: str,
         ClientRequestToken: str,
         Metadata: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CreateAppInstanceUserResponseTypeDef:
         """
         Creates a user under an Amazon Chime `AppInstance`.
@@ -132,7 +133,7 @@ class ChimeSDKIdentityClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client/#create_app_instance_user)
         """
 
-    def delete_app_instance(self, *, AppInstanceArn: str) -> None:
+    def delete_app_instance(self, *, AppInstanceArn: str) -> EmptyResponseMetadataTypeDef:
         """
         Deletes an `AppInstance` and all associated data asynchronously.
 
@@ -140,7 +141,9 @@ class ChimeSDKIdentityClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client/#delete_app_instance)
         """
 
-    def delete_app_instance_admin(self, *, AppInstanceAdminArn: str, AppInstanceArn: str) -> None:
+    def delete_app_instance_admin(
+        self, *, AppInstanceAdminArn: str, AppInstanceArn: str
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Demotes an `AppInstanceAdmin` to an `AppInstanceUser`.
 
@@ -148,7 +151,7 @@ class ChimeSDKIdentityClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client/#delete_app_instance_admin)
         """
 
-    def delete_app_instance_user(self, *, AppInstanceUserArn: str) -> None:
+    def delete_app_instance_user(self, *, AppInstanceUserArn: str) -> EmptyResponseMetadataTypeDef:
         """
         Deletes an `AppInstanceUser` .
 
@@ -158,7 +161,7 @@ class ChimeSDKIdentityClient(BaseClient):
 
     def deregister_app_instance_user_endpoint(
         self, *, AppInstanceUserArn: str, EndpointId: str
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Deregisters an `AppInstanceUserEndpoint` .
 
@@ -281,7 +284,7 @@ class ChimeSDKIdentityClient(BaseClient):
         self,
         *,
         AppInstanceArn: str,
-        AppInstanceRetentionSettings: "AppInstanceRetentionSettingsTypeDef"
+        AppInstanceRetentionSettings: AppInstanceRetentionSettingsTypeDef
     ) -> PutAppInstanceRetentionSettingsResponseTypeDef:
         """
         Sets the amount of time in days that a given `AppInstance` retains data.
@@ -296,7 +299,7 @@ class ChimeSDKIdentityClient(BaseClient):
         AppInstanceUserArn: str,
         Type: AppInstanceUserEndpointTypeType,
         ResourceArn: str,
-        EndpointAttributes: "EndpointAttributesTypeDef",
+        EndpointAttributes: EndpointAttributesTypeDef,
         ClientRequestToken: str,
         Name: str = ...,
         AllowMessages: AllowMessagesType = ...
@@ -308,7 +311,9 @@ class ChimeSDKIdentityClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client/#register_app_instance_user_endpoint)
         """
 
-    def tag_resource(self, *, ResourceARN: str, Tags: Sequence["TagTypeDef"]) -> None:
+    def tag_resource(
+        self, *, ResourceARN: str, Tags: Sequence[TagTypeDef]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Applies the specified tags to the specified Amazon Chime SDK identity resource.
 
@@ -316,7 +321,9 @@ class ChimeSDKIdentityClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_identity/client/#tag_resource)
         """
 
-    def untag_resource(self, *, ResourceARN: str, TagKeys: Sequence[str]) -> None:
+    def untag_resource(
+        self, *, ResourceARN: str, TagKeys: Sequence[str]
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Removes the specified tags from the specified Amazon Chime SDK identity
         resource.
